<?php

namespace Andy\InactiveMembers\Pub\Controller;

use XF\Pub\Controller\AbstractController;

class InactiveMembers extends AbstractController
{
	public function actionStats()
	{
		// check permission
		if (!\XF::visitor()->is_admin)
		{
			return $this->noPermission();
		}
		
		// get options
		$options = \XF::options();
		
		// get options from Admin CP -> Options -> Inactive members -> Minimum days
		$minimumDays = $options->inactiveMembersMinimumDays;
		
		// get options from Admin CP -> Options -> Inactive members -> Maximum days
		$maximumDays = $options->inactiveMembersMaximumDays;
	
		// get datelineMinimum
		$datelineMinimum = time() - (86400 * $minimumDays);
		
		// get datelineMaximum
		$datelineMaximum = time() - (86400 * $maximumDays);
		
		// get variables
		$resultsCount = 0;
		$resultsOptedOutCount = 0;
		
		// get results
		$finder = \XF::finder('XF:User');
		$results = $finder
			->where('email', '<>', '')
			->where('last_activity', '<', $datelineMinimum)
			->where('last_activity', '>=', $datelineMaximum)
			->where('user_state', 'valid')
			->where('is_banned', 0)
			->where('Option.is_discouraged', 0)
			->fetch();
		
		// check condition
		if (!empty($results))
		{
			$resultsCount = count($results);
		}
		
		// prepare viewParams
		$viewParams = [
			'resultsCount' => $resultsCount
		];
		
		// send to template
		return $this->view('Andy\InactiveMembers:Stats', 'andy_inactive_members_stats', $viewParams);		
	}
}		