<?php

namespace Andy\InactiveMembers\XF\Cron;

class InactiveMembers
{
	public static function runInactiveMembers()
	{	
		// calculate dateline
		$dateline = time() - (86400 * 30);
		
		//########################################
		// get options
		//########################################
		
		// get options
		$options = \XF::options();
		
		// get options from Admin CP -> Options -> Inactive members -> Exclude forums
		$excludeForums = $options->inactiveMembersExcludeForums;
		
		// get options from Admin CP -> Options -> Inactive members -> Exclude user groups
		$excludeUserGroups = $options->inactiveMembersExcludeUserGroups;
		
		// get options from Admin CP -> Options -> Inactive members -> Limit
		$limit = $options->inactiveMembersLimit;
		
		// get options from Admin CP -> Options -> Inactive members -> Minimum days
		$minimumDays = $options->inactiveMembersMinimumDays;

		// get options from Admin CP -> Options -> Inactive members -> Maximum days
		$maximumDays = $options->inactiveMembersMaximumDays;
		
		// get options from Admin CP -> Options -> Inactive members -> Sort Forum Titles
		$sortForumTitles = $options->inactiveMembersSortForumTitles;
		
		// get options from Admin CP -> Options -> Inactive members -> Test Username
		$testUsername = $options->inactiveMembersTestUsername;
		
		// check condition
		if (empty($excludeUserGroups)) 
		{
			$excludeUserGroups = array(
				0 => 0
			);
		}

		//########################################
		// get conditions
		//########################################
		
		$conditions[] = ['node_id', '<>', 0];
	
		foreach($excludeForums as $value)
		{
			$conditions[] = ['node_id', '<>', $value];
		}
		
		//########################################
		// get threads
		//########################################				

		// check condition
		if (!$sortForumTitles)
		{
			$finder = \XF::finder('XF:Thread');
				$threads = $finder
				->with('Forum')
				->with('Forum.Node')
				->where('post_date', '>', $dateline)
				->where('discussion_state', '=', 'visible')
				->where('discussion_type', '<>', 'redirect')
				->where($conditions)
				->order('view_count', 'DESC')
				->limit($limit)
				->fetch();	
		}
		
		// check condition
		if ($sortForumTitles)
		{
			$finder = \XF::finder('XF:Thread');
				$threads = $finder
				->with('Forum')
				->with('Forum.Node')
				->where('post_date', '>', $dateline)
				->where('discussion_state', '=', 'visible')
				->where('discussion_type', '<>', 'redirect')
				->where($conditions)
				->order('Forum.Node.title', 'ASC')
				->order('view_count', 'DESC')
				->limit($limit)
				->fetch();	
		}

		// continue only if we have posts
		if (count($threads) > 0)
		{
			//########################################
			// get members - testUsername
			//########################################	
            
            // get result
            $finder = \XF::finder('XF:User');
            $result = $finder
                ->where('username', $testUsername)
                ->fetchOne();

            // check condition
            if (!empty($result['user_id']))
            {
                $userId = $result['user_id'];
                
                $finder = \XF::finder('XF:User');
                $members = $finder
                    ->where('user_id', $userId)
                    ->fetch();
            }
			
			//########################################
			// get members
			//########################################					

            // check condition
			if (empty($userId))
			{
				// convert to UNIX timestamp
				$datelineMin = time() - (86400 * $minimumDays);	
				$datelineMax = time() - (86400 * $maximumDays);
                
                // get members
                $finder = \XF::finder('XF:User');
                $members = $finder
                    ->where('email', '<>', '')
                    ->where('last_activity', '<', $datelineMin)
					->where('last_activity', '>', $datelineMax)
                    ->where('user_state', 'valid')
                    ->where('is_banned', 0)
                    ->where('Option.receive_admin_email', 1)
                    ->where('Option.is_discouraged', 0)
                    ->fetch();
			}

			//########################################
			// send emails
			//########################################

			// foreach members
			foreach ($members as $member)
			{
				// define variable
				$bypass = '';
				
				// get userGroupId
				$userGroupId = $member['user_group_id'];
				
				// check condition
				if (!empty($userGroupId))
				{
					// get match
					$match = in_array($userGroupId, $excludeUserGroups);				

					// check condition
					if ($match)
					{
						$bypass = 'yes';
					}
				}
				
				// get secondaryGroupIds
				$secondaryGroupIds = $member['secondary_group_ids'];
				
				// check condition
				if (!empty($secondaryGroupIds) AND !empty($excludeUserGroups))
				{
					// get match
					$match = array_intersect($secondaryGroupIds, $excludeUserGroups);				

					// check condition
					if ($match)
					{
						$bypass = 'yes';
					}
				}

				// continue if not bypass
				if ($bypass != 'yes')
				{					
					$mail = \XF::app()->mailer()->newMail();

					$user = \XF::app()->find('XF:User', $member['user_id']);
					$mail->setToUser($user);

					$mail->setTemplate('andy_inactivemembers', [
						'username' => $member['username'],
						'threads' => $threads
					]);

					$mail->queue();
				}
			}
		}	
	}
}